#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       dialogs.py
#       
#       Copyright 2009-2011 Sandro Mani <manisandro@gmail.com>
#       
#       This program is free software: you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation, either version 3 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program.  If not, see <http://www.gnu.org/licenses/>.

# This file contains a variety of dialogs

import webbrowser
import gtk
import os
import gettext
_ = gettext.gettext

def question_dialog(primaryText, secondaryText=None, parent=None):
	""" Displays a yes/no question dialog.
			primaryText (str): the primary text, bold
			secondaryText=None (str): the secondary text
			parent=None (gtk.Window): the parent window
	"""
	dialog=gtk.MessageDialog(parent, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, message_format=primaryText)
	dialog.format_secondary_text(secondaryText)
	dialog.set_default_response(gtk.RESPONSE_YES)
	response=dialog.run()
	dialog.destroy()
	if response==gtk.RESPONSE_NO:
		return 0
	elif response==gtk.RESPONSE_YES:
		return 1	
	else:
		return 2

def error_dialog(primaryText, secondaryText=None, parent=None):
	""" Displays an error dialog.
			primaryText (str): the primary text, bold
			secondaryText=None (str): the secondary text
			parent=None (gtk.Window): the parent window
	"""
	dialog=gtk.MessageDialog(parent, 0, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, message_format=primaryText)
	dialog.format_secondary_text(secondaryText)
	dialog.run()
	dialog.destroy()

def save_text(curdir, filename, parent=None):
	""" Displays the save output dialog.
			filename (str): the default filename
			parent (gtk.Window): the parent window
	"""
	dialog = gtk.FileChooserDialog(_("Save Output..."), parent, gtk.FILE_CHOOSER_ACTION_SAVE, (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
	dialog.set_local_only(False)
	if curdir!=None:
		dialog.set_current_folder(curdir)
	dialog.set_current_name(filename)
	dialog.set_do_overwrite_confirmation(True)
	filter = gtk.FileFilter()
	filter.set_name(_("Text Files"))
	filter.add_pattern("*.txt")
	dialog.add_filter(filter)
	
	response = dialog.run()
	filename=dialog.get_filename()
	dialog.destroy()
	if response == gtk.RESPONSE_OK:
		return filename
	else:
		return ""

class image_open_dialog:
	def __init__(self, parent):
		""" Initializes the image open dialog.
				parent (gtk.Window): the parent window
		"""
		self.dialog=gtk.FileChooserDialog(_("Choose Image(s)..."), parent, gtk.FILE_CHOOSER_ACTION_OPEN, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OPEN, gtk.RESPONSE_OK))
		self.dialog.set_local_only(False)
		self.dialog.set_default_response(gtk.RESPONSE_OK)
		self.dialog.set_select_multiple(True)
		filefilter = gtk.FileFilter()
		filefilter.set_name(_("Images and PDFs"))
		filefilter.add_pixbuf_formats()
		filefilter.add_mime_type("application/pdf")
		filefilter.add_pattern("*.pdf")
		self.dialog.add_filter(filefilter)
	
	def run(self, curdir=None):
		""" Runs the dialog
				cudir=None (str): the directory opened at run
		"""
		if curdir!=None:
			self.dialog.set_current_folder(curdir)
		response=self.dialog.run()
		self.dialog.hide()
		if response == gtk.RESPONSE_OK:
			return self.dialog.get_filenames()
		else:
			return []

class image_save_dialog:
	def __init__(self, parent):
		""" Initializes the image save dialog.
				parent (gtk.Window): the parent window
		"""
		self.dialog=gtk.FileChooserDialog(_("Choose Output Image..."), parent, gtk.FILE_CHOOSER_ACTION_SAVE, (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
		self.dialog.set_local_only(False)
		self.dialog.set_default_response(gtk.RESPONSE_OK)
		filefilter = gtk.FileFilter()
		filefilter.set_name(_("Images"))
		filefilter.add_mime_type("image/png")
		filefilter.add_mime_type("image/jpeg")
		filefilter.add_mime_type("image/tif")
		filefilter.add_pattern("*.png")
		filefilter.add_pattern("*.jpg")
		filefilter.add_pattern("*.tif")
		filefilter.add_pattern("*.tiff")
		self.dialog.add_filter(filefilter)
	
	def run(self, curfile=None):
		""" Runs the dialog
				cudir=None (str): the directory opened at run
		"""
		if curfile!=None:
			self.dialog.set_current_folder(os.path.dirname(curfile))
			self.dialog.set_current_name(os.path.basename(curfile))
		response=self.dialog.run()
		self.dialog.hide()
		if response == gtk.RESPONSE_OK:
			return self.dialog.get_filename()
		else:
			return None

manual=os.path.join('file://'+os.path.dirname(__file__),'manual.html')

def help(section=''):
	webbrowser.open(manual+'#'+section)
